@@ -5,7 +5,7 @@ from jupyter_server.utils import url_path_join
 
 from .ydoc import YDocWebSocketHandler
 
-__version__ = "0.1.12"
+__version__ = "0.1.13"
 
 
 def _jupyter_server_extension_points() -> List[Dict[str, str]]:
@@ -17,3 +17,7 @@ def _load_jupyter_server_extension(serverapp: jupyter_server.serverapp.ServerApp
     host_pattern = ".*$"
     route_pattern = url_path_join(web_app.settings["base_url"], r"/api/yjs/(.*)")
     web_app.add_handlers(host_pattern, [(route_pattern, YDocWebSocketHandler)])
+
+
+# Backward compatibility for classic notebook based start-up (e.g. Binder)
+load_jupyter_server_extension = _load_jupyter_server_extension
